@@ -271,7 +271,7 @@ class TorchTagger:
         # predict
         prediction = self.model(processed_text)
         prediction_item = prediction.argmax().item()
-        prediction_prob = prediction[0][prediction_item].item()
+        prediction_prob = np.exp(prediction[0][prediction_item].item())
         # get class label if asked
         if get_label:
             prediction_item = self.label_reverse_index[prediction_item]
